from setuptools import setup
setup(
    name='rocket-launcher',
    version='0.2.4',
    author='who',
    author_email='who@whooami.me',
    scripts=[
        'rocket-launcher',
        'rockets/bin/configure-file-browser',
        'rockets/bin/configure-multiplexer',
        'rockets/bin/configure-version-controller',
        'rockets/bin/configure-secure_shell',
        'rockets/bin/set-terminal-fish',
        'rockets/bin/set-text-editor',
    ],
    packages=['rockets'],
)



import os,sys,subprocess
path=__file__.split('/')
del path[-1]
path='/'.join(path)
for i in os.listdir(path):
    if i.split('.')[-1]=='py' and i!='__init__.py':
        f=open(path+'/'+i,'r')
        exec(f.read())
